"""Pylons environment configuration"""
import os

from mako.lookup import TemplateLookup
from pylons import config
from pylons.error import handle_mako_error
from sqlalchemy import engine_from_config

from scribeengine.lib import app_globals
from scribeengine.lib import helpers
from scribeengine.config.routing import make_map
from scribeengine.model import init_model, Variable
from scribeengine.model.meta import Session

def load_environment(global_conf, app_conf):
    """Configure the Pylons environment via the ``pylons.config``
    object
    """
    # Setup the SQLAlchemy database engine
    engine = engine_from_config(app_conf, 'sqlalchemy.')
    init_model(engine)

    theme_name = None
    if not app_conf.get('setup-app'):
        # Pull out theme variable
        theme = Session.query(Variable).get(u'theme')
        if theme:
            theme_name = theme.value

    # Set up Pylons paths
    root = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
    template_paths = []
    static_paths = []
    if theme_name:
        theme_dir = os.path.join(app_conf[u'paths.themes'], theme_name)
        template_paths.append(os.path.join(theme_dir, 'templates'))
        static_paths.append(os.path.join(theme_dir, 'public'))
    template_paths.append(os.path.join(root, 'templates'))
    static_paths.append(os.path.join(root, 'public'))

    paths = dict(
        root=root,
        controllers=os.path.join(root, 'controllers'),
        static_files=static_paths,
        templates=template_paths
    )

    # Initialize config with the basic options
    config.init_app(global_conf, app_conf, package='scribeengine', paths=paths)

    config['routes.map'] = make_map()
    config['pylons.app_globals'] = app_globals.Globals()
    config['pylons.h'] = helpers

    # Create the Mako TemplateLookup, with the default auto-escaping
    config['pylons.app_globals'].mako_lookup = TemplateLookup(
        directories=paths['templates'],
        error_handler=handle_mako_error,
        module_directory=os.path.join(app_conf['cache_dir'], 'templates'),
        input_encoding='utf-8', default_filters=['escape'],
        imports=['from webhelpers.html import escape'])

    # CONFIGURATION OPTIONS HERE (note: all config options will override
    # any Pylons config options)
